summaryrefslogtreecommitdiffstats
path: root/korganizer/korganizer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/korganizer.cpp')
-rw-r--r--korganizer/korganizer.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/korganizer/korganizer.cpp b/korganizer/korganizer.cpp
index dba9c2c8..f2ec01f2 100644
--- a/korganizer/korganizer.cpp
+++ b/korganizer/korganizer.cpp
@@ -177,10 +177,10 @@ void KOrganizer::newMainWindow( const KURL &url )
void KOrganizer::readSettings()
{
// read settings from the KConfig, supplying reasonable
// defaults where none are to be found
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
mActionManager->readSettings();
@@ -192,7 +192,7 @@ void KOrganizer::writeSettings()
{
kdDebug(5850) << "KOrganizer::writeSettings" << endl;
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
mActionManager->writeSettings();
config->sync();
@@ -266,12 +266,12 @@ KURL KOrganizer::getCurrentURL() const
return mActionManager->url();
}
-void KOrganizer::saveProperties( KConfig *config )
+void KOrganizer::saveProperties( TDEConfig *config )
{
return mActionManager->saveProperties( config );
}
-void KOrganizer::readProperties( KConfig *config )
+void KOrganizer::readProperties( TDEConfig *config )
{
return mActionManager->readProperties( config );
}
@@ -177,10 +177,10 @@ void KOrganizer::newMainWindow( const KURL &url )
void KOrganizer::readSettings()
{
- // read settings from the KConfig, supplying reasonable
+ // read settings from the TDEConfig, supplying reasonable
// defaults where none are to be found